@@ -188,7 +188,12 @@ dm_paste_fks <- function(dm) {
   fpks$non_default_parent_key_cols <- ""
   fpks$non_default_parent_key_cols[need_non_default] <- paste0(", ", deparse_keys(fpks$parent_key_cols[need_non_default]))
 
-  glue("dm::dm_add_fk({tick_if_needed(fpks$child_table)}, {deparse_keys(fpks$child_fk_cols)}, {tick_if_needed(fpks$parent_table)}{fpks$non_default_parent_key_cols})")
+  on_delete <- if_else(
+    fpks$on_delete != "no_action",
+    glue(", on_delete = \"{fpks$on_delete}\""),
+    "")
+
+  glue("dm::dm_add_fk({tick_if_needed(fpks$child_table)}, {deparse_keys(fpks$child_fk_cols)}, {tick_if_needed(fpks$parent_table)}{fpks$non_default_parent_key_cols}{on_delete})")
 }
 
 dm_paste_color <- function(dm) {
