@@ -14,6 +14,17 @@ dm_upgrade <- function(dm, quiet) {
       .x <- .x[c("ref_column", "table", "column")]
       .x
     }))
+    dm <- new_dm3(def, zoomed = is_zoomed(dm), validate = FALSE)
+  }
+
+  if (version < 2) {
+    # FIXME: Can't give unconditional message, because IDE can tickle object in environment,
+    # and this also produces a message. Don't emit message when calling str()?
+    if (!quiet) {
+      message("Upgrading dm object created with dm <= 0.2.4.")
+    }
+    def <- unclass(dm)$def
+    def$fks <- list_of(!!!map(def$fks, mutate, on_delete = "no_action"))
     dm <- new_dm3(def, zoomed = is_zoomed(dm))
   }
 
